@@ -1,7 +1,6 @@
-#圆柱部分
 from p.__init__ import *
-pai2='π' #下面要用到，提前放上来 
-def part_yz():
+pai2='π'
+def part_yz():#圆柱
     while True:
         r=input('请输入半径:')#半径输入
         try:
@@ -30,20 +29,18 @@ def part_yz():
             print('除数不能为0，emmm，2年级小孩都知道')
         if r<=0 or H<=0:
             print('虽然输入成功，但是为什么弹出选择模式，自己想想为什么')
-            print('0.1秒后切换模式')
-            dd(0.1)
+            switch(0.1)
             break
         print(' ')
         if xxx>5 or xxx<=0:
             end1=sj.now()-start
             print('即将\033[10;31m退出\033[0m,','本次使用时间:',end1,'\n程序将在5秒后关闭,谢谢使用')
-            dd(5)
+            exitings(5)
             tc('谢谢使用')
         elif xxx==5:
             print('-'*40)
             print('切换模式')
-            print('0.1秒后切换模式')
-            dd(0.1)
+            switch(0.1)
             break
         elif xxx==1:
             dw()
@@ -57,7 +54,7 @@ def part_yz():
             if r<=0 and H<=0 or (S or C or Sc or sD or sU or d)<=0 : #if重点检查区域
                 print('请重新输入半径和高，因为其中一个小于0或者数太小了，就像0.0001这样的，所以停止运行了')
                 print('请选择模式，再次尝试运行')
-                dd(0.5)
+                switch(0.5)
                 break
             elif r>0 and H>0:
                 dw()
@@ -82,8 +79,8 @@ def part_yz():
             V=sU*H
             if r<=0 and H<=0 or (S or C or Sc or sD or sU or d)<=0 : #if重点检查区域
                 print('请重新输入半径和高，因为其中一个小于0或者数太小了，就像0.0001这样的，所以停止运行了')
-                print('请重新打开，再次尝试运行')
-                dd(0.5)
+                print('请重新选择圆柱，再次尝试运行')
+                switch(0.5)
                 break
             elif r>0 and H>0:
                 dw()
@@ -108,8 +105,8 @@ def part_yz():
             V=sU*H
             if r<=0 and H<=0 or (S or C or Sc or sD or sU or d)<=0 : #if重点检查区域
                 print('请重新输入半径和高，因为其中一个小于0或者数太小了，就像0.0001这样的，所以停止运行了')
-                print('请重新打开，再次尝试()运行')
-                dd(0.5)
+                print('请重新选择圆柱，再次尝试运行')
+                switch(0.5)
                 break
             elif r>0 and H>0:
                 dw()
@@ -132,8 +129,7 @@ def part_yz():
             except ZeroDivisionError:
                 print('除数不能为0，emmm，2年级小孩都知道')       
             if defpi<3 or defpi >3.2:
-                    print('0.3秒后切换模式')
-                    dd(0.3)
+                    switch(0.3)
                     break
             if defpi >=3 and defpi <3.2:
                 sU=r*r*defpi#上圆s
@@ -146,7 +142,7 @@ def part_yz():
                 if r<=0 and H<=0 or (S or C or Sc or sD or sU or d)<=0 : #if重点检查区域
                     print('请重新输入半径和高，因为其中一个小于0或者数太小了，就像0.0001这样的，所以停止运行了')
                     print('请重新打开，再次尝试运行')
-                    dd(0.5)
+                    switch(0.5)
                     break
                 elif r>0 and H>0:
                     dw()
@@ -164,5 +160,5 @@ def part_yz():
         else:
             end1=sj.now()-start
             print('即将\033[10;31m退出\033[0m,','本次使用时间:',end1,'\n程序将在5秒后关闭,谢谢使用')
-            dd(5)
+            exitings(5)
             tc('谢谢使用')
\ No newline at end of file
